window.Gleam.initSearch([{"doc":"file_streams","title":"file_streams","content":"# Gleam File Streams\n\nThis Gleam library provides access to Erlang&#39;s file streams for reading and\nwriting files. If you don&#39;t require streaming behavior then consider using\n[`simplifile`](https://hex.pm/packages/simplifile) instead.\n\nThis library only supports the Erlang target.\n\n[![Package Version](https://img.shields.io/hexpm/v/file_streams)](https://hex.pm/packages/file_streams)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/file_streams/)\n\n## Example\n\nAdd this library to your project:\n\n```sh\ngleam add file_streams\n```\n\nThe following code writes data to a file using a write stream, reads it back in\nusing a binary file stream, then reads it again with a text file stream.\n\n```gleam\nimport file_streams/read_stream\nimport file_streams/read_stream_error\nimport file_streams/read_text_stream\nimport file_streams/write_stream\nimport gleam/bit_array\n\n// Write file\nlet assert Ok(ws) = write_stream.open(&quot;test.txt&quot;)\nlet assert Ok(Nil) = write_stream.write_string(ws, &quot;Hello, world!\\n&quot;)\nlet assert Ok(Nil) = write_stream.write_bytes(ws, &lt;&lt;&quot;12&quot;:utf8&gt;&gt;)\nlet assert Ok(Nil) = write_stream.close(ws)\n\n// Read file as a binary stream\nlet assert Ok(rs) = read_stream.open(&quot;test.txt&quot;)\n\nlet assert Ok(bytes) = read_stream.read_bytes(rs, 14)\nlet assert Ok(&quot;Hello, world!\\n&quot;) = bit_array.to_string(bytes)\nlet assert Ok([49, 50]) = read_stream.read_list(rs, read_stream.read_uint8, 2)\nlet assert Error(read_stream_error.EndOfStream) = read_stream.read_bytes(rs, 1)\n\nlet assert Ok(Nil) = read_stream.close(rs)\n\n// Read file as a text stream so UTF-8 characters and lines can be read\nlet assert Ok(rts) = read_text_stream.open(&quot;test.txt&quot;)\n\nlet assert Ok(&quot;Hello&quot;) = read_text_stream.read_chars(rts, 5)\nlet assert Ok(&quot;, world!\\n&quot;) = read_text_stream.read_line(rts)\nlet assert Ok(&quot;12&quot;) = read_text_stream.read_line(rts)\nlet assert Error(read_stream_error.EndOfStream) = read_text_stream.read_line(rts)\n\nlet assert Ok(Nil) = read_text_stream.close(rts)\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/file_streams/&gt;.\n\n## License\n\nThis library is published under the MIT license, a copy of which is included.\n","url":"index.html"},{"doc":"file_streams/file_encoding","title":"FileEncoding","content":"pub type FileEncoding {\n  Unicode\n}\n File encodings for text streams. Right now only Unicode UTF-8 is supported.\n\nUnicode\n\n\nSynonyms:\nfile_streams/file_encoding.FileEncoding\nfile_streams/file_encoding FileEncoding","url":"file_streams/file_encoding.html#FileEncoding"},{"doc":"file_streams/file_encoding","title":"file_streams/file_encoding","content":"","url":"file_streams/file_encoding.html"},{"doc":"file_streams/file_error","title":"FileError","content":"pub type FileError {\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n  InvalidUnicode\n  NoTranslation(a: FileEncoding, b: FileEncoding)\n}\n The reasons why a file system operation could fail in Erlang. Most of these\n map to underlying POSIX errors.\n\nEacces\n Permission denied.\n\nEagain\n Resource temporarily unavailable.\n\nEbadf\n Bad file number\n\nEbadmsg\n Bad message.\n\nEbusy\n File busy.\n\nEdeadlk\n Resource deadlock avoided.\n\nEdeadlock\n On most architectures, same as `Edeadlk`. On some architectures, it\n \n means &quot;File locking deadlock error.&quot;\n\nEdquot\n Disk quota exceeded.\n\nEexist\n File already exists.\n\nEfault\n Bad address in system call argument.\n\nEfbig\n File too large.\n\nEftype\n Inappropriate file type or format. Usually caused by trying to set the\n \n &quot;sticky bit&quot; on a regular file (not a directory).\n\nEintr\n Interrupted system call.\n\nEinval\n Invalid argument.\n\nEio\n I/O error.\n\nEisdir\n Illegal operation on a directory.\n\nEloop\n Too many levels of symbolic links.\n\nEmfile\n Too many open files.\n\nEmlink\n Too many links.\n\nEmultihop\n Multihop attempted.\n\nEnametoolong\n Filename too long\n\nEnfile\n File table overflow\n\nEnobufs\n No buffer space available.\n\nEnodev\n No such device.\n\nEnolck\n No locks available.\n\nEnolink\n Link has been severed.\n\nEnoent\n No such file or directory.\n\nEnomem\n Not enough memory.\n\nEnospc\n No space left on device.\n\nEnosr\n No STREAM resources.\n\nEnostr\n Not a STREAM.\n\nEnosys\n Function not implemented.\n\nEnotblk\n Block device required.\n\nEnotdir\n Not a directory.\n\nEnotsup\n Operation not supported.\n\nEnxio\n No such device or address.\n\nEopnotsupp\n Operation not supported on socket.\n\nEoverflow\n Value too large to be stored in data type.\n\nEperm\n Not owner.\n\nEpipe\n Broken pipe.\n\nErange\n Result too large.\n\nErofs\n Read-only file system.\n\nEspipe\n Invalid seek.\n\nEsrch\n No such process.\n\nEstale\n Stale remote file handle.\n\nEtxtbsy\n Text file busy.\n\nExdev\n Cross-domain link.\n\nInvalidUnicode\n Invalid Unicode data was encountered when reading text.\n\nNoTranslation(a: FileEncoding, b: FileEncoding)\n Unicode data that can&#39;t be converted to/from the relevant encoding was\n encountered when reading text.\n\nSynonyms:\nfile_streams/file_error.FileError\nfile_streams/file_error FileError","url":"file_streams/file_error.html#FileError"},{"doc":"file_streams/file_error","title":"file_streams/file_error","content":"","url":"file_streams/file_error.html"},{"doc":"file_streams/read_stream_error","title":"ReadStreamError","content":"pub type ReadStreamError {\n  EndOfStream\n  OtherFileError(error: FileError)\n}\n Errors that can occur when using a read stream.\n\nEndOfStream\n The end of the stream was reached before the requested data could\n be read.\n\nOtherFileError(error: FileError)\n A file error occurred while reading from the stream.\n\nSynonyms:\nfile_streams/read_stream_error.ReadStreamError\nfile_streams/read_stream_error ReadStreamError","url":"file_streams/read_stream_error.html#ReadStreamError"},{"doc":"file_streams/read_stream_error","title":"file_streams/read_stream_error","content":"","url":"file_streams/read_stream_error.html"},{"doc":"file_streams/read_stream","title":"ReadStream","content":"pub type ReadStream\n A stream that data can be read from.\n\n\nSynonyms:\nfile_streams/read_stream.ReadStream\nfile_streams/read_stream ReadStream","url":"file_streams/read_stream.html#ReadStream"},{"doc":"file_streams/read_stream","title":"close","content":"pub fn close(stream: ReadStream) -&gt; Result(Nil, ReadStreamError)\n Closes a read stream.\n\nSynonyms:\nfile_streams/read_stream.close\nfile_streams/read_stream close","url":"file_streams/read_stream.html#close"},{"doc":"file_streams/read_stream","title":"open","content":"pub fn open(filename: String) -&gt; Result(ReadStream, FileError)\n Opens a new read stream that reads binary or text data from a file. Once the\n stream is no longer needed it should be closed with `close()`.\n\nSynonyms:\nfile_streams/read_stream.open\nfile_streams/read_stream open","url":"file_streams/read_stream.html#open"},{"doc":"file_streams/read_stream","title":"read_bytes","content":"pub fn read_bytes(\n  stream: ReadStream,\n  byte_count: Int,\n) -&gt; Result(BitArray, ReadStreamError)\n Reads bytes from a read stream. The returned number of bytes may be fewer\n than the number that was requested if the end of the stream was reached.\n \n If the end of the stream is encountered before any bytes can be read then\n `EndOfStream` is returned.\n\nSynonyms:\nfile_streams/read_stream.read_bytes\nfile_streams/read_stream read_bytes","url":"file_streams/read_stream.html#read_bytes"},{"doc":"file_streams/read_stream","title":"read_bytes_exact","content":"pub fn read_bytes_exact(\n  stream: ReadStream,\n  byte_count: Int,\n) -&gt; Result(BitArray, ReadStreamError)\n Reads the requested number of bytes from a read stream. If the requested\n number of bytes can&#39;t be read prior to reaching the end of the stream then\n `EndOfStream` is returned.\n\nSynonyms:\nfile_streams/read_stream.read_bytes_exact\nfile_streams/read_stream read_bytes_exact","url":"file_streams/read_stream.html#read_bytes_exact"},{"doc":"file_streams/read_stream","title":"read_float32_be","content":"pub fn read_float32_be(\n  stream: ReadStream,\n) -&gt; Result(Float, ReadStreamError)\n Reads a big-endian 32-bit float from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_float32_be\nfile_streams/read_stream read_float32_be","url":"file_streams/read_stream.html#read_float32_be"},{"doc":"file_streams/read_stream","title":"read_float32_le","content":"pub fn read_float32_le(\n  stream: ReadStream,\n) -&gt; Result(Float, ReadStreamError)\n Reads a little-endian 32-bit float from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_float32_le\nfile_streams/read_stream read_float32_le","url":"file_streams/read_stream.html#read_float32_le"},{"doc":"file_streams/read_stream","title":"read_float64_be","content":"pub fn read_float64_be(\n  stream: ReadStream,\n) -&gt; Result(Float, ReadStreamError)\n Reads a big-endian 64-bit float from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_float64_be\nfile_streams/read_stream read_float64_be","url":"file_streams/read_stream.html#read_float64_be"},{"doc":"file_streams/read_stream","title":"read_float64_le","content":"pub fn read_float64_le(\n  stream: ReadStream,\n) -&gt; Result(Float, ReadStreamError)\n Reads a little-endian 64-bit float from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_float64_le\nfile_streams/read_stream read_float64_le","url":"file_streams/read_stream.html#read_float64_le"},{"doc":"file_streams/read_stream","title":"read_int16_be","content":"pub fn read_int16_be(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a big-endian 16-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int16_be\nfile_streams/read_stream read_int16_be","url":"file_streams/read_stream.html#read_int16_be"},{"doc":"file_streams/read_stream","title":"read_int16_le","content":"pub fn read_int16_le(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a little-endian 16-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int16_le\nfile_streams/read_stream read_int16_le","url":"file_streams/read_stream.html#read_int16_le"},{"doc":"file_streams/read_stream","title":"read_int32_be","content":"pub fn read_int32_be(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a big-endian 32-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int32_be\nfile_streams/read_stream read_int32_be","url":"file_streams/read_stream.html#read_int32_be"},{"doc":"file_streams/read_stream","title":"read_int32_le","content":"pub fn read_int32_le(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a little-endian 32-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int32_le\nfile_streams/read_stream read_int32_le","url":"file_streams/read_stream.html#read_int32_le"},{"doc":"file_streams/read_stream","title":"read_int64_be","content":"pub fn read_int64_be(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a big-endian 64-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int64_be\nfile_streams/read_stream read_int64_be","url":"file_streams/read_stream.html#read_int64_be"},{"doc":"file_streams/read_stream","title":"read_int64_le","content":"pub fn read_int64_le(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a little-endian 64-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int64_le\nfile_streams/read_stream read_int64_le","url":"file_streams/read_stream.html#read_int64_le"},{"doc":"file_streams/read_stream","title":"read_int8","content":"pub fn read_int8(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads an 8-bit signed integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_int8\nfile_streams/read_stream read_int8","url":"file_streams/read_stream.html#read_int8"},{"doc":"file_streams/read_stream","title":"read_list","content":"pub fn read_list(\n  stream: ReadStream,\n  item_read_fn: fn(ReadStream) -&gt; Result(a, ReadStreamError),\n  item_count: Int,\n) -&gt; Result(List(a), ReadStreamError)\n Reads the specified type the requested number of times, e.g. two\n little-endian 32-bit integers, or four big-endian 64-bit floating point\n values, and returns the values in a list.\n \n ## Examples\n \n \n read_list(stream, read_stream.read_int32_le, 2)\n |&gt; Ok([1, 2])\n\n read_list(stream, read_stream.read_float64_be, 4)\n |&gt; Ok([1.0, 2.0])\n \n\nSynonyms:\nfile_streams/read_stream.read_list\nfile_streams/read_stream read_list","url":"file_streams/read_stream.html#read_list"},{"doc":"file_streams/read_stream","title":"read_uint16_be","content":"pub fn read_uint16_be(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a big-endian 16-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint16_be\nfile_streams/read_stream read_uint16_be","url":"file_streams/read_stream.html#read_uint16_be"},{"doc":"file_streams/read_stream","title":"read_uint16_le","content":"pub fn read_uint16_le(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a little-endian 16-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint16_le\nfile_streams/read_stream read_uint16_le","url":"file_streams/read_stream.html#read_uint16_le"},{"doc":"file_streams/read_stream","title":"read_uint32_be","content":"pub fn read_uint32_be(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a big-endian 32-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint32_be\nfile_streams/read_stream read_uint32_be","url":"file_streams/read_stream.html#read_uint32_be"},{"doc":"file_streams/read_stream","title":"read_uint32_le","content":"pub fn read_uint32_le(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a little-endian 32-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint32_le\nfile_streams/read_stream read_uint32_le","url":"file_streams/read_stream.html#read_uint32_le"},{"doc":"file_streams/read_stream","title":"read_uint64_be","content":"pub fn read_uint64_be(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a big-endian 64-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint64_be\nfile_streams/read_stream read_uint64_be","url":"file_streams/read_stream.html#read_uint64_be"},{"doc":"file_streams/read_stream","title":"read_uint64_le","content":"pub fn read_uint64_le(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads a little-endian 64-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint64_le\nfile_streams/read_stream read_uint64_le","url":"file_streams/read_stream.html#read_uint64_le"},{"doc":"file_streams/read_stream","title":"read_uint8","content":"pub fn read_uint8(\n  stream: ReadStream,\n) -&gt; Result(Int, ReadStreamError)\n Reads an 8-bit unsigned integer from a read stream.\n\nSynonyms:\nfile_streams/read_stream.read_uint8\nfile_streams/read_stream read_uint8","url":"file_streams/read_stream.html#read_uint8"},{"doc":"file_streams/read_stream","title":"file_streams/read_stream","content":" Use Erlang binary file read streams in Gleam.","url":"file_streams/read_stream.html"},{"doc":"file_streams/read_text_stream","title":"ReadTextStream","content":"pub type ReadTextStream\n A stream that UTF-8 text can be read from.\n\n\nSynonyms:\nfile_streams/read_text_stream.ReadTextStream\nfile_streams/read_text_stream ReadTextStream","url":"file_streams/read_text_stream.html#ReadTextStream"},{"doc":"file_streams/read_text_stream","title":"close","content":"pub fn close(\n  stream: ReadTextStream,\n) -&gt; Result(Nil, ReadStreamError)\n Closes a text stream.\n\nSynonyms:\nfile_streams/read_text_stream.close\nfile_streams/read_text_stream close","url":"file_streams/read_text_stream.html#close"},{"doc":"file_streams/read_text_stream","title":"open","content":"pub fn open(\n  filename: String,\n) -&gt; Result(ReadTextStream, FileError)\n Opens a new stream that reads UTF-8 text data from a file. Once the stream\n is no longer needed it should be closed with `close()`.\n\nSynonyms:\nfile_streams/read_text_stream.open\nfile_streams/read_text_stream open","url":"file_streams/read_text_stream.html#open"},{"doc":"file_streams/read_text_stream","title":"read_chars","content":"pub fn read_chars(\n  stream: ReadTextStream,\n  count: Int,\n) -&gt; Result(String, ReadStreamError)\n Reads the next `count` UTF-8 characters from a text stream. The returned\n number of characters may be fewer than the number that was requested if the\n end of the stream was reached.\n\nSynonyms:\nfile_streams/read_text_stream.read_chars\nfile_streams/read_text_stream read_chars","url":"file_streams/read_text_stream.html#read_chars"},{"doc":"file_streams/read_text_stream","title":"read_line","content":"pub fn read_line(\n  stream: ReadTextStream,\n) -&gt; Result(String, ReadStreamError)\n Reads the next line of UTF-8 text from a stream. The returned string value\n will include the newline `\\n` character. If the stream contains a Windows\n newline `\\r\\n` then only the `\\n` will be returned.\n\nSynonyms:\nfile_streams/read_text_stream.read_line\nfile_streams/read_text_stream read_line","url":"file_streams/read_text_stream.html#read_line"},{"doc":"file_streams/read_text_stream","title":"file_streams/read_text_stream","content":" Use Erlang text file read streams in Gleam.","url":"file_streams/read_text_stream.html"},{"doc":"file_streams/write_stream","title":"WriteStream","content":"pub type WriteStream\n A stream that binary data can be written to.\n\n\nSynonyms:\nfile_streams/write_stream.WriteStream\nfile_streams/write_stream WriteStream","url":"file_streams/write_stream.html#WriteStream"},{"doc":"file_streams/write_stream","title":"close","content":"pub fn close(stream: WriteStream) -&gt; Result(Nil, FileError)\n Closes a write stream.\n \n Because write streams are opened with delayed writes enabled to improve\n performance, closing a stream can return an error related to flushing\n recently written data to disk.\n\nSynonyms:\nfile_streams/write_stream.close\nfile_streams/write_stream close","url":"file_streams/write_stream.html#close"},{"doc":"file_streams/write_stream","title":"open","content":"pub fn open(filename: String) -&gt; Result(WriteStream, FileError)\n Creates a new write stream that writes binary data to a file. Once the\n stream is no longer needed it should be closed with `close`.\n\nSynonyms:\nfile_streams/write_stream.open\nfile_streams/write_stream open","url":"file_streams/write_stream.html#open"},{"doc":"file_streams/write_stream","title":"sync","content":"pub fn sync(stream: WriteStream) -&gt; Result(Nil, FileError)\n Syncs a write stream which ensures that any write buffers kept by the\n operating system (not by the Erlang runtime system) are written to disk.\n \n Because write streams are opened with delayed writes enabled to improve\n performance, syncing can return an error related to flushing recently\n written data to disk.\n\nSynonyms:\nfile_streams/write_stream.sync\nfile_streams/write_stream sync","url":"file_streams/write_stream.html#sync"},{"doc":"file_streams/write_stream","title":"write_bytes","content":"pub fn write_bytes(\n  stream: WriteStream,\n  bytes: BitArray,\n) -&gt; Result(Nil, FileError)\n Writes bytes to a write stream.\n\nSynonyms:\nfile_streams/write_stream.write_bytes\nfile_streams/write_stream write_bytes","url":"file_streams/write_stream.html#write_bytes"},{"doc":"file_streams/write_stream","title":"write_line","content":"pub fn write_line(\n  stream: WriteStream,\n  line: String,\n) -&gt; Result(Nil, FileError)\n Writes a line to a write stream along with a trailing newline character.\n\nSynonyms:\nfile_streams/write_stream.write_line\nfile_streams/write_stream write_line","url":"file_streams/write_stream.html#write_line"},{"doc":"file_streams/write_stream","title":"write_string","content":"pub fn write_string(\n  stream: WriteStream,\n  string: String,\n) -&gt; Result(Nil, FileError)\n Writes a UTF-8 string to a write stream.\n\nSynonyms:\nfile_streams/write_stream.write_string\nfile_streams/write_stream write_string","url":"file_streams/write_stream.html#write_string"},{"doc":"file_streams/write_stream","title":"file_streams/write_stream","content":" Use Erlang file write streams in Gleam.","url":"file_streams/write_stream.html"}]);